/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.guard.internal.authentication;

import static java.util.concurrent.TimeUnit.MINUTES;
import java.util.Date;

/**
 * {@link AuthenticationTokenValidator} validates an {@link GuardAuthenticationToken}
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v7.8.2
 */
public class AuthenticationTokenValidator {

    /**
     * Checks whether an {@link GuardAuthenticationToken} is still valid or not
     *
     * @param authToken The token to verify
     * @return True, if the token is still valid, false otherwise
     */
    public static boolean isValid(GuardAuthenticationToken authToken) {
        if (authToken != null) {
            if (authToken.getMinutesValid() > -1) {

                if (authToken.getMinutesValid() == 0) {
                    //Token is valid as long the groupware session is valid
                    return true;
                }

                //Token is only valid for a given period
                Date createdOn = authToken.getCreatedOn();
                Date expirationDate = new Date(createdOn.getTime() + MINUTES.toMillis(authToken.getMinutesValid()));
                return expirationDate.getTime() >= System.currentTimeMillis();
            }
            else {
                //A token which should only be use once
                return !authToken.isUsed();
            }
        }
        return false;
    }
}
